From 17f783457b8dbd182f8184ef77c72d57d7c8da8b Mon Sep 17 00:00:00 2001
From: Justin Clarke Casey
Date: Thu, 8 Jan 2009 18:50:46 +0000
Subject: * refactor: move code for sending a message to all users in a region
to the DialogModule
---
.../Region/Environment/Interfaces/IDialogModule.cs | 20 +++++++++++++++++---
1 file changed, 17 insertions(+), 3 deletions(-)
(limited to 'OpenSim/Region/Environment/Interfaces')
diff --git a/OpenSim/Region/Environment/Interfaces/IDialogModule.cs b/OpenSim/Region/Environment/Interfaces/IDialogModule.cs
index a296c5a..4a648d6 100644
--- a/OpenSim/Region/Environment/Interfaces/IDialogModule.cs
+++ b/OpenSim/Region/Environment/Interfaces/IDialogModule.cs
@@ -34,7 +34,8 @@ namespace OpenSim.Region.Environment.Interfaces
public interface IDialogModule
{
///
- /// Send a non-modal alert message to a particular user.
+ /// Send a non-modal alert message to a particular user. This can disappear from the user's view after a
+ /// small interval.
///
///
///
@@ -73,9 +74,22 @@ namespace OpenSim.Region.Environment.Interfaces
void SendAlertToUser(string firstName, string lastName, string message, bool modal);
///
/// Send an alert messages to all avatars in the scene.
///
///
- void SendGeneralAlert(string message);
+ void SendGeneralAlert(string message);
+
+ ///
+ /// Send a notification to all users in the scene. This notification should remain around until the
+ /// user explicitly dismisses it.
+ ///
+ ///
+ /// On the Linden Labs Second Client (as of 1.21), this is a big blue box message on the upper right of the
+ /// screen.
+ ///
+ /// The user sending the message
+ /// The name of the user doing the sending
+ /// The message being sent to the user
+ void SendNotificationToUsersInRegion(UUID fromAvatarID, string fromAvatarName, string message);
}
}
@@ -73,9 +74,22 @@ namespace OpenSim.Region.Environment.Interfaces
void SendAlertToUser(string firstName, string lastName, string message, bool modal);
///
- /// Send an alert messages to all avatars in the scene.
+ /// Send an alert message to all users in the scene.
///
///
--
cgit v1.1